#!/usr/bin/env python



class CronUpdater():

    def generate_cron_schedule(self):
      import ConfigParser
      config = ConfigParser.ConfigParser()
      config.read("/etc/default/mythbuntu-bare-client.conf")
      managed = config.get("General", "managed")
      schedule = config.get("Backup", "schedule")
      day = config.get("Backup", "day")
      hour = config.get("Backup", "hour")
      minute = config.get("Backup", "minute")
      weekday = config.get("Backup", "weekday")
      f = open("/etc/cron.d/mythbuntu-bare","w")
      if not schedule == "disabled":
          f.write(minute+" "+hour+" "+day+" "+"*"+" "+weekday+" root /usr/share/mythbuntu-bare/backup-task.py\n")
      if managed == True:
          f.write("41 * * * * root /usr/share/mythbuntu-bare/update-task.py\n")
      f.close()
